==> vscode-coding-tracker-server-0.5.0.tgz: package/frontend/src/js/i18n/ru.js <==
module.exports = {
	title_summary: 'Итоговый отчет',
	title_24hs: 'Отчет за последние 24 часа',
	title_projects: 'Группировка по проектам',
	title_projects_tip: ' (нажмите на элемент в диаграмме для деталей)',
	title_languages: 'Языки',
	title_files: 'Группировка по файлам',
	title_computers: 'Компьютеры',
	title_welcome: 'VSCode Coding Tracker отчет',

	title_share: 'Поделиться',

	title_author: 'Автор',
	title_version: 'Версия',
	title_help: 'Помощь',
	title_license: 'Лицензия',
	title_components: 'Компоненты',
	title_connect: 'Ссылки',
	
	title_server_version: 'Версия сервера:',
	title_storage_version: 'Версия хранилища:',

	title_files_in_proj: 'Файлы проекта:',
	title_last_xx_days: 'Последние',

	title_totally_1: 'Всего: ',
	title_totally_2: 'ч. просмотра; ',
	title_totally_3: 'ч. печатания',
	
	full_report: 'Полный отчет',

	option_7_days: '7 дней',
	option_30_days: '30 дней',
	option_365_days: '365 дней',

	word_top: 'Популярные',
	word_all: 'Все',
	word_day: 'дней',

	link_github_repo_server: 'репозиторий сервера',
	link_github_repo_extension: 'репозиторий расширения',
	link_vscode_marketplace: 'VSCode расширения',

	show_welcome: 'welcome info',	
	
	//Welcome Info
  welcome_subtitle: '',
	welcome_intro: 'Введение:',
	welcome_watching_time: 'Время просмотра(включая время печатания)',
	welcome_coding_time: 'Время, потраченное на печатание', 
	welcome_tips: 'Подсказки:',
	welcome_tips_click_hover_title: 'Нажмите или наведите мышь на диаграмму',
	welcome_tips_click_hover: 'Наведите для детальной информации. Кликните по столбцу с проектом для получения детального отчета по проекту.',
	welcome_tips_language_title: 'Изменение языка',
	welcome_tips_language: 'Выбор языка находится вверху страницы возле иконки:',
	welcome_contribution: 'Сотрудничество:',
	welcome_contribution_1: 'Если у вас есть идея или вы нашли ошибку, пожалуйста создайте ',
	welcome_contribution_2: ' или ',
	welcome_btn_close: 'OK. Спрятать эту информацию',
	welcome_reopen: 'Вы можете открыть это окно снова кликнув по кнопке "welcome info"',

	//share
	share_content: 'Текст',
	share_font_size: 'Размер текста',
	share_mark_line: 'Добавить линию',
	share_mark_line_max: 'Максимум',
	share_mark_line_average: 'Средний',
	share_mark_line_min: 'Минимальный',
	share_tip: '(Нажмите на точку в диаграмме, чтоб добавить маркер со временем)',
	share_btn: 'Сохранить'
};

==> vscode-coding-tracker-server-0.6.0.tgz: package/frontend/src/js/i18n/ru.js <==
module.exports = {
	title_summary: 'Итоговый отчет',
	title_24hs: 'Отчет за последние 24 часа',
	title_projects: 'Группировка по проектам',
	title_projects_tip: ' (нажмите на элемент в диаграмме для деталей)',
	title_languages: 'Языки',
	title_files: 'Группировка по файлам',
	title_computers: 'Компьютеры',
	title_welcome: 'VSCode Coding Tracker отчет',

	title_share: 'Поделиться',

	title_author: 'Автор',
	title_version: 'Версия',
	title_help: 'Помощь',
	title_license: 'Лицензия',
	title_components: 'Компоненты',
	title_connect: 'Ссылки',

	title_server_version: 'Версия сервера:',
	title_storage_version: 'Версия хранилища:',

	title_files_in_proj: 'Файлы проекта:',
	title_last_xx_days: 'Последние',

	title_totally_1: 'Всего: ',
	title_totally_2: 'просмотра; ',

	full_report: 'Полный отчет',

	option_7_days: '7 дней',
	option_30_days: '30 дней',
	option_365_days: '365 дней',

	word_top: 'Популярные',
	word_all: 'Все',
	word_day: 'дней',

	show_welcome: 'welcome info',

	// link in the bottom
	link_github_repo_server: 'репозиторий сервера',
	link_github_repo_extension: 'репозиторий расширения',
	link_vscode_marketplace: 'VSCode расширения',

	// welcome Info
	welcome_subtitle: '',
	welcome_intro: 'Введение:',
	welcome_watching_time: 'Время просмотра(включая время печатания)',
	welcome_coding_time: 'Время, потраченное на печатание',
	welcome_tips: 'Подсказки:',
	welcome_tips_click_hover_title: 'Нажмите или наведите мышь на диаграмму',
	welcome_tips_click_hover: 'Наведите для детальной информации. Кликните по столбцу с проектом для получения детального отчета по проекту.',
	welcome_tips_language_title: 'Изменение языка',
	welcome_tips_language: 'Выбор языка находится вверху страницы возле иконки:',
	welcome_contribution: 'Сотрудничество:',
	welcome_contribution_1: 'Если у вас есть идея или вы нашли ошибку, пожалуйста создайте ',
	welcome_contribution_2: ' или ',
	welcome_btn_close: 'OK. Спрятать эту информацию',
	welcome_reopen: 'Вы можете открыть это окно снова кликнув по кнопке "welcome info"',

	// share
	share_content: 'Текст',
	share_font_size: 'Размер текста',
	share_mark_line: 'Добавить линию',
	share_mark_line_max: 'Максимум',
	share_mark_line_average: 'Средний',
	share_mark_line_min: 'Минимальный',
	share_tip: '(Нажмите на точку в диаграмме, чтоб добавить маркер со временем)',
	share_btn: 'Сохранить'
};
